@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,9 +12,8 @@
 #
 ##############################################################################
 """Adding implementation tests
-
-$Id: test_adding.py 87370 2008-06-13 16:53:53Z ccomb $
 """
+import doctest
 import unittest
 
 import zope.interface
@@ -25,8 +24,10 @@ from zope.interface import implements, Interface, directlyProvides
 from zope.publisher.browser import TestRequest
 from zope.publisher.interfaces.browser import IBrowserRequest
 from zope.publisher.browser import BrowserView
+from zope.browsermenu.interfaces import AddMenu
+from zope.browsermenu.interfaces import IMenuItemType, IBrowserMenu
+from zope.browsermenu.menu import BrowserMenuItem, BrowserMenu
 from zope.security.interfaces import ForbiddenAttribute
-from zope.testing.doctestunit import DocTestSuite
 from zope.exceptions.interfaces import UserError
 from zope.traversing.api import getParent
 from zope.traversing.browser import AbsoluteURL
@@ -36,9 +37,6 @@ from zope.traversing.interfaces import IContainmentRoot
 
 from zope.app.testing import ztapi
 from zope.app.testing.placelesssetup import PlacelessSetup, setUp, tearDown
-from zope.app.publisher.interfaces.browser import AddMenu
-from zope.app.publisher.interfaces.browser import IMenuItemType, IBrowserMenu
-from zope.app.publisher.browser.menu import BrowserMenuItem, BrowserMenu
 from zope.app.container.interfaces import IAdding
 from zope.app.container.interfaces import IObjectAddedEvent
 from zope.app.container.interfaces import IContainerNamesContainer
@@ -162,7 +160,7 @@ class Test(PlacelessSetup, unittest.TestCase):
         self.assertRaises(UserError, adding.action, id='bar')
 
         # missing id
-        self.assertRaises(UserError, adding.action, type_name='foo')
+        self.assertRaises(KeyError, adding.action, type_name='foo')
 
         # bad type_name
         self.assertRaises(ComponentLookupError, adding.action,
@@ -579,7 +577,7 @@ def test_isSingleMenuItem_with_ICNC():
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(Test),
-        DocTestSuite(setUp=setUp, tearDown=tearDown),
+        doctest.DocTestSuite(setUp=setUp, tearDown=tearDown),
         ))
 
 if __name__=='__main__':
